@@ -2,6 +2,7 @@ from .state import ServiceState
 from .common import CommonService, ProxyService, JsOrc, MetaProperties, Kube
 from .redis import RedisService
 from .task import TaskService
+from .stripe import StripeService
 from .mail import MailService
 from .prometheus import PrometheusService
 from .elastic import ElasticService
@@ -15,6 +16,7 @@ __all__ = [
     "ProxyService",
     "RedisService",
     "TaskService",
+    "StripeService",
     "MailService",
     "PrometheusService",
     "ElasticService",
