@@ -4,6 +4,6 @@ META_CONFIG = {
     "automation": False,
     "backoff_interval": 10,
     "namespace": "default",
-    "keep_alive": ["promon", "redis", "task", "mail"],
+    "keep_alive": ["promon", "redis", "task", "mail", "elastic"],
     "kubernetes": KUBERNETES_CONFIG,
 }
