@@ -7,6 +7,7 @@ from jaseci.svc import (
     MailService,
     RedisService,
     TaskService,
+    StripeService,
     PrometheusService,
     ElasticService,
     ServiceState as Ss,
@@ -94,12 +95,14 @@ class MetaService(CommonService, MetaProperties):
             h.task = self.get_service("task", h)
             h.mail = self.get_service("mail", h)
             h.elastic = self.get_service("elastic", h)
+            h.stripe = self.get_service("stripe", h)
 
             if not self.is_automated():
                 h.mail.start(h)
                 h.redis.start(h)
                 h.task.start(h)
                 h.elastic.start(h)
+                h.stripe.start(h)
 
         return h
 
@@ -140,6 +143,7 @@ class MetaService(CommonService, MetaProperties):
         self.add_service_builder("mail", MailService)
         self.add_service_builder("promon", PrometheusService)
         self.add_service_builder("elastic", ElasticService)
+        self.add_service_builder("stripe", StripeService)
 
 
 def interval_check(signum, frame):
